<?php
/**
 * Register settings.
 *
 * @author  WeCreativez
 * @package WooCommerce Added to Cart Popup
 * @version 1.0.0
 */

defined( 'ABSPATH' ) || exit;

if ( ! function_exists( 'atcp_register_settings' ) ) {
	/**
	 * Register plugin settings.
	 *
	 * @since 1.0.0
	 *
	 * @param array $settings   Settings array.
	 */
	function atcp_register_settings( $settings ) {
		// Appearance settings.
		$settings[] = array(
			'id'     => 'atcp_appearance_settings',
			'title'  => __( 'Appearance Settings', 'woo-atcp' ),

			'fields' => array(
				array(
					'id'      => 'atcp_primary_background_color',
					'title'   => __( 'Primary Background Color', 'woo-atcp' ),
					'type'    => 'color',
					'default' => '#03CB54',
					/* translators: %s: Hex color code of the primary background color. */
					'desc'    => sprintf( __( 'Select the primary background color. <br /> Default: %s', 'woo-atcp' ), '<code>#03cb54</code>' ),
					'classes' => 'atcp-color-selector',
				),
				array(
					'id'      => 'atcp_primary_text_color',
					'title'   => __( 'Primary Text Color', 'woo-atcp' ),
					'type'    => 'color',
					'default' => '#ffffff',
					/* translators: %s: Hex color code of the primary text color. */
					'desc'    => sprintf( __( 'Select the primary text color. <br /> Default: %s', 'woo-atcp' ), '<code>#ffffff</code>' ),
					'classes' => 'atcp-color-selector',
				),
				array(
					'id'      => 'atcp_secondary_background_color',
					'title'   => __( 'Secondary Background Color', 'woo-atcp' ),
					'type'    => 'color',
					'default' => '#333333',
					/* translators: %s: Hex color code of the secondary background color. */
					'desc'    => sprintf( __( 'Select the secondary background color. <br /> Default: %s', 'woo-atcp' ), '<code>#333333</code>' ),
					'classes' => 'atcp-color-selector',
				),
				array(
					'id'      => 'atcp_secondary_text_color',
					'title'   => __( 'Secondary Text Color', 'woo-atcp' ),
					'type'    => 'color',
					'default' => '#ffffff',
					/* translators: %s: Hex color code of the primary text color. */
					'desc'    => sprintf( __( 'Select the secondary text color. <br /> Default: %s', 'woo-atcp' ), '<code>#ffffff</code>' ),
					'classes' => 'atcp-color-selector',
				),
				array(
					'id'      => 'atcp_popup_design_mode',
					'title'   => __( 'Popup Design Mode', 'woo-atcp' ),
					'type'    => 'select',
					'default' => 'none',
					'desc'    => __( 'Select the popup design mode.', 'woo-atcp' ),
					'options' => array(
						'none'       => __( 'Default', 'woo-atcp' ),
						'dark_mode'  => __( 'Dark Mode', 'woo-atcp' ),
						'glass_mode' => __( 'Glass Mode', 'woo-atcp' ),
					),
				),
			),
		);

		// Behaviour settings.
		$settings[] = array(
			'id'     => 'atcp_appearance_behaviour_settings',
			'title'  => __( 'Behaviour', 'woo-atcp' ),
			'page'   => 'atcp_appearance_settings',

			'fields' => array(
				array(
					'id'      => 'atcp_popup_animation',
					'title'   => __( 'Popup Animation', 'woo-atcp' ),
					'type'    => 'select',
					'default' => 'animate__jackInTheBox',
					'desc'    => __( 'Select the popup animation. <br /> Default: <code>Jack In The Box</code>', 'woo-atcp' ),
					'options' => array(
						'none'                  => __( 'None', 'woo-atcp' ),

						'animate__bounce'       => __( 'Bounce', 'woo-atcp' ),
						'animate__flash'        => __( 'Flash', 'woo-atcp' ),
						'animate__pulse'        => __( 'Pulse', 'woo-atcp' ),
						'animate__rubberBand'   => __( 'Rubber Band', 'woo-atcp' ),
						'animate__shakeX'       => __( 'shakeX', 'woo-atcp' ),
						'animate__shakeY'       => __( 'shakeY', 'woo-atcp' ),
						'animate__headShake'    => __( 'Head Shake', 'woo-atcp' ),
						'animate__swing'        => __( 'Swing', 'woo-atcp' ),
						'animate__tada'         => __( 'Tada', 'woo-atcp' ),
						'animate__wobble'       => __( 'Wobble', 'woo-atcp' ),
						'animate__jello'        => __( 'Jello', 'woo-atcp' ),
						'animate__heartBeat'    => __( 'Heart Beat', 'woo-atcp' ),

						'animate__backInDown'   => __( 'Back In Down', 'woo-atcp' ),
						'animate__backInLeft'   => __( 'Back In Left', 'woo-atcp' ),
						'animate__backInRight'  => __( 'Back In Right', 'woo-atcp' ),
						'animate__backInUp'     => __( 'Back In Up', 'woo-atcp' ),

						'animate__jackInTheBox' => __( 'Jack In The Box', 'woo-atcp' ),
						'animate__rollIn'       => __( 'Roll In', 'woo-atcp' ),
					),
				),
				array(
					'id'      => 'atcp_popup_loader',
					'title'   => __( 'Popup Loader', 'woo-atcp' ),
					'type'    => 'select',
					'default' => 'none',
					'desc'    => __( 'Select the popup loader. <br /> Default: <code>None</code>', 'woo-atcp' ),
					'options' => array(
						'none'     => __( 'None', 'woo-atcp' ),
						'loader_1' => __( 'Loader 1', 'woo-atcp' ),
						'loader_2' => __( 'Loader 2', 'woo-atcp' ),
					),
				),
				array(
					'id'      => 'atcp_hide_popup_overlay',
					'title'   => __( 'Hide Popup Overlay', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'no',
					'desc'    => __( 'Enable, if you want to hide transparent popup overlay.', 'woo-atcp' ),
				),
				array(
					'id'      => 'atcp_hide_popup_automatically',
					'title'   => __( 'Hide Popup Automatically', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'no',
					'desc'    => __( 'You can enable/ disable auto close popup after x seconds.', 'woo-atcp' ),
				),
				array(
					'id'      => 'atcp_hide_popup_automatically_after',
					'title'   => __( 'Hide Popup After', 'woo-atcp' ),
					'type'    => 'number',
					'default' => '5',
					'desc'    => __( 'Enter the time in seconds.', 'woo-atcp' ),
					'classes' => 'small-text',
					'min'     => '0',
				),
				array(
					'id'      => 'atcp_vibrate_on_add_to_cart',
					'title'   => __( 'Vibrate On Add To Cart', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'yes',
					'desc'    => __( 'You can enable/ disable vibration while add to cart on mobile.', 'woo-atcp' ),
				),
			),
		);

		// Customization settings.
		$settings[] = array(
			'id'     => 'atcp_customization_settings',
			'title'  => __( 'Customization', 'woo-atcp' ),
			'page'   => 'atcp_appearance_settings',

			'fields' => array(
				array(
					'id'      => 'atcp_custom_css',
					'title'   => __( 'Custom CSS', 'woo-atcp' ),
					'type'    => 'textarea',
					'default' => '',
					'desc'    => __( 'Plugin related custom CSS.', 'woo-atcp' ),
					'rows'    => 8,
					'style'   => array(
						'background' => '#263238',
						'color'      => '#ffffff',
						'max-width'  => '100%',
						'width'      => '500px',
					),
				),
			),
		);

		// Popup settings.
		$settings[] = array(
			'id'     => 'atcp_popup_settings',
			'title'  => __( 'Popup Settings', 'woo-atcp' ),

			'fields' => array(
				array(
					'id'      => 'atcp_addded_to_cart_message',
					'title'   => __( 'Added To Cart Message', 'woo-atcp' ),
					'type'    => 'text',
					'default' => 'Added to cart',
				),
				array(
					'id'      => 'atcp_hide_on_product_page',
					'title'   => __( 'Hide On Product Page', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'no',
					'desc'    => __( 'Hide/ Show', 'woo-atcp' ),
				),
				array(
					'id'      => 'atcp_hide_on_product_archive',
					'title'   => __( 'Hide On Product Archive', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'no',
					'desc'    => __( 'Hide/ Show', 'woo-atcp' ),
				),
				array(
					'id'      => 'atcp_hide_on_all_other_pages',
					'title'   => __( 'Hide On All Other Pages', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'no',
					'desc'    => __( 'Hide/ Show', 'woo-atcp' ),
				),
			),
		);

		// Product settings.
		$settings[] = array(
			'id'     => 'atcp_popup_product_settings',
			'title'  => __( 'Product On Popup Settings', 'woo-atcp' ),
			'page'   => 'atcp_popup_settings',

			'fields' => array(
				array(
					'id'      => 'atcp_hide_product_title',
					'title'   => __( 'Hide Product Title', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'no',
					'desc'    => __( 'Hide/ Show', 'woo-atcp' ),
				),
				array(
					'id'      => 'atcp_hide_product_price',
					'title'   => __( 'Hide Product Price', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'no',
					'desc'    => __( 'Hide/ Show', 'woo-atcp' ),
				),
				array(
					'id'      => 'atcp_hide_product_image',
					'title'   => __( 'Hide Product Image', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'no',
					'desc'    => __( 'Hide/ Show', 'woo-atcp' ),
				),
				array(
					'id'      => 'atcp_hide_quantity_buttons',
					'title'   => __( 'Hide Quantity Buttons', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'no',
					'desc'    => __( 'Hide/ Show', 'woo-atcp' ),
				),
			),
		);

		// Cart on popup settings.
		$settings[] = array(
			'id'     => 'atcp_popup_cart_settings',
			'title'  => __( 'Cart On Popup Settings', 'woo-atcp' ),
			'page'   => 'atcp_popup_settings',

			'fields' => array(
				array(
					'id'      => 'atcp_hide_cart_shipping_total',
					'title'   => __( 'Hide Shipping Total', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'no',
					'desc'    => __( 'Hide/ Show', 'woo-atcp' ),
				),
				array(
					'id'      => 'atcp_cart_shipping_text',
					'title'   => __( 'Shipping Total Label', 'woo-atcp' ),
					'type'    => 'text',
					'default' => 'Shipping:',
				),
				array(
					'id'      => 'atcp_hide_cart_total',
					'title'   => __( 'Hide Cart Total', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'no',
					'desc'    => __( 'Hide/ Show', 'woo-atcp' ),
				),
				array(
					'id'      => 'atcp_cart_total_text',
					'title'   => __( 'Cart Total Lable', 'woo-atcp' ),
					'type'    => 'text',
					'default' => 'Cart Total:',
				),
			),
		);

		// Continue Shopping button settings.
		$settings[] = array(
			'id'     => 'atcp_popup_continue_shopping_button_settings',
			'title'  => __( 'Continue Shopping Button Settings', 'woo-atcp' ),
			'page'   => 'atcp_popup_settings',

			'fields' => array(
				array(
					'id'      => 'atcp_continue_shopping_cart_button',
					'title'   => __( 'Hide Continue Shopping Button', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'yes',
					'desc'    => __( 'Hide/ Show', 'woo-atcp' ),
				),
				array(
					'id'      => 'atcp_continue_shopping_button_text',
					'title'   => __( 'Button Text', 'woo-atcp' ),
					'type'    => 'text',
					'default' => 'Continue Shopping',
				),
				array(
					'id'      => 'atcp_continue_shopping_button_type',
					'title'   => __( 'Button Type', 'woo-atcp' ),
					'type'    => 'radio',
					'default' => 'secondary',
					'options' => array(
						'primary'   => __( 'Primary', 'woo-atcp' ),
						'secondary' => __( 'Secondary', 'woo-atcp' ),
					),
					'desc'    => __( 'Select the button type.', 'woo-atcp' ),
				),

			),
		);

		// Cart button settings.
		$settings[] = array(
			'id'     => 'atcp_popup_cart_button_settings',
			'title'  => __( 'Cart Button Settings', 'woo-atcp' ),
			'page'   => 'atcp_popup_settings',

			'fields' => array(
				array(
					'id'      => 'atcp_hide_cart_button',
					'title'   => __( 'Hide Cart Button', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'no',
					'desc'    => __( 'Hide/ Show', 'woo-atcp' ),
				),
				array(
					'id'      => 'atcp_cart_button_text',
					'title'   => __( 'Cart Button Text', 'woo-atcp' ),
					'type'    => 'text',
					'default' => 'View Cart',
				),
				array(
					'id'      => 'atcp_cart_button_url',
					'title'   => __( 'Cart Button URL', 'woo-atcp' ),
					'type'    => 'url',
					'default' => wc_get_cart_url(),
				),
				array(
					'id'      => 'atcp_cart_button_type',
					'title'   => __( 'Button Type', 'woo-atcp' ),
					'type'    => 'radio',
					'default' => 'secondary',
					'options' => array(
						'primary'   => __( 'Primary', 'woo-atcp' ),
						'secondary' => __( 'Secondary', 'woo-atcp' ),
					),
					'desc'    => __( 'Select the button type.', 'woo-atcp' ),
				),
			),
		);

		// Checkout button settings.
		$settings[] = array(
			'id'     => 'atcp_popup_checkout_button_settings',
			'title'  => __( 'Checkout Button Settings', 'woo-atcp' ),
			'page'   => 'atcp_popup_settings',

			'fields' => array(
				array(
					'id'      => 'atcp_hide_checkout_button',
					'title'   => __( 'Hide Checkout Button', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'no',
					'desc'    => __( 'Hide/ Show', 'woo-atcp' ),
				),
				array(
					'id'      => 'atcp_checkout_button_text',
					'title'   => __( 'Checkout Button Text', 'woo-atcp' ),
					'type'    => 'text',
					'default' => 'Checkout',
				),
				array(
					'id'      => 'atcp_checkout_button_url',
					'title'   => __( 'Checkout Button URL', 'woo-atcp' ),
					'type'    => 'url',
					'default' => wc_get_checkout_url(),
				),
				array(
					'id'      => 'atcp_checkout_button_type',
					'title'   => __( 'Button Type', 'woo-atcp' ),
					'type'    => 'radio',
					'default' => 'primary',
					'options' => array(
						'primary'   => __( 'Primary', 'woo-atcp' ),
						'secondary' => __( 'Secondary', 'woo-atcp' ),
					),
					'desc'    => __( 'Select the button type.', 'woo-atcp' ),
				),
			),
		);

		// Suggested products settings.
		$settings[] = array(
			'id'     => 'atcp_suggested_products_settings',
			'title'  => __( 'Suggested Products', 'woo-atcp' ),

			'fields' => array(
				array(
					'id'      => 'atcp_suggested_products_status',
					'title'   => __( 'Suggested Products', 'woo-atcp' ),
					'type'    => 'checkbox',
					'default' => 'no',
					'desc'    => __( 'Enable/ Disable', 'woo-atcp' ),
				),
				array(
					'id'      => 'atcp_suggested_products_content',
					'title'   => __( 'Content', 'woo-atcp' ),
					'type'    => 'wp_editor',
					'default' => '[atcp_related_products]',
					/* translators: %s: URL to the plugin shortcode page. */
					'desc'    => sprintf( __( 'Click <a href="%s" target="_blank">here</a> to know more about suggested products shortcodes.<br /> You also can use any shortcode or text here to display after product on the added to cart popup.', 'woo-atcp' ), admin_url( 'admin.php?page=woocommerce-added-to-cart-popup&tab=shortcodes' ) ),
				),
			),
		);

		return $settings;
	}

	add_filter( 'atcp_register_settings', 'atcp_register_settings' );
}
