<?php
/**
 * AJAX.
 *
 * @author  WeCreativez
 * @package WooCommerce Added to Cart Popup
 * @version 1.0.0
 */

defined( 'ABSPATH' ) || exit;

/**
 * AJAX class.
 *
 * Manage all AJAX related operations.
 *
 * @since 1.0.0
 */
class ATCP_AJAX extends WC_AJAX {

	/**
	 * Hook in ajax handlers.
	 */
	public static function init() {
		self::add_ajax_events();
	}

	/**
	 * Add custom ajax events here.
	 */
	public static function add_ajax_events() {
		// woocommerce_EVENT => nopriv.
		$ajax_events = array(
			'atcp_added_to_cart_popup'     => true,
			'atcp_update_product_quantity' => true,
		);

		foreach ( $ajax_events as $ajax_event => $nopriv ) {
			add_action( 'wp_ajax_woocommerce_' . $ajax_event, array( __CLASS__, $ajax_event ) );
			if ( $nopriv ) {
				add_action( 'wp_ajax_nopriv_woocommerce_' . $ajax_event, array( __CLASS__, $ajax_event ) );
				// WC AJAX can be used for frontend ajax requests.
				add_action( 'wc_ajax_' . $ajax_event, array( __CLASS__, $ajax_event ) );
			}
		}
	}

	/**
	 * AJAX added to cart popup.
	 *
	 * @since 1.0.0
	 */
	public static function atcp_added_to_cart_popup() {
		// phpcs:ignore WordPress.Security.NonceVerification.Missing
		if ( ! isset( $_POST['action'] ) || 'atcp_added_to_cart_popup' !== $_POST['action'] || ! isset( $_POST['add-to-cart'] ) ) {
			die();
		}

		// Get woocommerce errors notice.
		$errors = wc_get_notices( 'error' );

		if ( $errors ) {
			wc_clear_notices(); // Clear other notice.
			wp_send_json(
				array(
					'errors' => $errors,
				)
			);
		} else {
			// Trigger action for added to cart in ajax.
			do_action( 'woocommerce_ajax_added_to_cart', intval( $_POST['add-to-cart'] ) ); // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals, WordPress.Security.NonceVerification.Missing

			wc_clear_notices(); // Clear other notice.
			WC_AJAX::get_refreshed_fragments();
		}

		die();
	}

	/**
	 * Update product quantity.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public static function atcp_update_product_quantity() {
		// phpcs:ignore WordPress.Security.NonceVerification.Missing
		$cart_item_key = isset( $_POST['cart_item_key'] ) ? sanitize_text_field( wp_unslash( $_POST['cart_item_key'] ) ) : '';
		$quantity      = isset( $_POST['quantity'] ) ? intval( $_POST['quantity'] ) : 0; // phpcs:ignore WordPress.Security.NonceVerification.Missing

		if ( $cart_item_key ) {
			WC()->cart->set_quantity( $cart_item_key, $quantity );

			atcp_set_last_added_cart_key( $cart_item_key );
		}

		// Response.
		die( wp_json_encode( WC_AJAX::get_refreshed_fragments() ) );
	}

}

ATCP_AJAX::init();
