<?php
/**
 * Plugin init.
 *
 * @author  WeCreativez
 * @package WooCommerce Added to Cart Popup
 * @version 1.0.0
 */

defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'ATCP_Init' ) ) {
	/**
	 * Plugin initialization.
	 *
	 * @since 1.0.0
	 */
	class ATCP_Init {

		/**
		 * Class init.
		 *
		 * @since 1.0.0
		 */
		public function __construct() {
			$this->load_files();

			add_action( 'init', array( $this, 'update_plugin_settings' ) );
		}

		/**
		 * Load files.
		 *
		 * @since 1.0.0
		 *
		 * @return void
		 */
		public function load_files() {

			// Global files.
			require_once ATCP_PLUGIN_PATH . 'includes/atcp-functions.php';
			require_once ATCP_PLUGIN_PATH . 'includes/class-atcp-settings.php';

			// Admin files.
			if ( is_admin() ) {
				require_once ATCP_PLUGIN_PATH . 'includes/admin/class-atcp-admin-notices.php';
				require_once ATCP_PLUGIN_PATH . 'includes/admin/class-atcp-admin-enqueue.php';
				require_once ATCP_PLUGIN_PATH . 'includes/admin/class-atcp-admin-menu.php';

				// Admin Settings.
				require_once ATCP_PLUGIN_PATH . 'includes/admin/settings/atcp-admin-settings.php';

				// Plugin updater.
				require_once ATCP_PLUGIN_PATH . 'includes/admin/class-atcp-admin-plugin-updater.php';

			}

			// Frontend files.
			require_once ATCP_PLUGIN_PATH . 'includes/class-atcp-ajax.php';
			require_once ATCP_PLUGIN_PATH . 'includes/class-atcp-icons.php';
			require_once ATCP_PLUGIN_PATH . 'includes/class-atcp-enqueue.php';
			require_once ATCP_PLUGIN_PATH . 'includes/class-atcp-shortcodes.php';
			require_once ATCP_PLUGIN_PATH . 'includes/class-atcp-cart-popup.php';
		}

		/**
		 * Run plugin settings update, if new version installed over the old version.
		 *
		 * @since 1.0.0
		 *
		 * @return void
		 */
		public function update_plugin_settings() {
			if ( ATCP_PLUGIN_VER !== get_option( 'atcp_plugin_version' ) ) {

				// Run installation.
				atcp_plugin_installation();
			}
		}

	}

	global $atcp_init;

	$atcp_init = new ATCP_Init();

}
